@@ -1137,8 +1137,10 @@ char *l2_util_vasprintf(const char *fmt, va_list ap)
     if ((s = malloc(rv+1)) == NULL)
         return NULL;
     ap = apbak;
-    if ((rv = l2_util_vsprintf(s, rv+1, fmt, ap)) == -1)
+    if ((rv = l2_util_vsprintf(s, rv+1, fmt, ap)) == -1) {
+        free(s);
         return NULL;
+    }
     return s;
 }
 
